#config-multipaas

CONFIG-CHAIN - WITH CLOUD DEFAULTS!

[Config-multiPaaS](https://github.com/ryanj/config-multipaas) is a [`config-chain`](https://github.com/dominictarr/config-chain) wrapper that includes automatic support for several popular cloud deployment targets ([OpenShift](http://openshift.com/), [Heroku](http://heroku.com/)).

It works by checking the system environment (`process.env`) for common cloud configuration strings, automatically supplimenting your application's default configs.

Configuration objects generated by `config-multipaass` are valid instances of [`config-chain`](https://www.npmjs.org/package/config-chain), making it an easy drop-in replacement.  See the [`config-chain README`](https://github.com/dominictarr/config-chain) for detailed usage notes:

``` js
  //npm install config-multipaas
  var cc = require('config-multipaas')

  // Config-chain works as usual, while loading automatic configuration 
  // strings from popular cloud hosting environments:
  var config = cc({my_app_config_1: "foo", my_app_config_2: "bar"})
```

Your server's `PORT` number and bind `IP` configuration should now be automatically resolved.  If the server-provided config strings are missing, local development defaults are returned instead.

## Listen up

Make sure to pass `config.get('PORT')` and `config.get('IP')` to your app's `listen` function:

```js
app.listen(config.get('PORT'), config.get('IP'), function () {
  console.log("Listening on "+config.get('IP')+", port "+config.get('PORT'))
});
```

That's it! 

## Default Configs

[`Config-chain`](https://github.com/dominictarr/config-chain/#configchai    n-lives-to-serve-only-you) is easy to extend, making it easy to provide your own configuration layers on top of [these cloud configuration defaults](https://github.com/ryanj/config-multipaas/blob/master/cloud-defaults.js):

config.get(VARNAME) | READ_FROM | DEFAULT_VALUE
--------------------|-----------|---------------
IP                  | BIND_IP, OPENSHIFT_NODEJS_IP | 0.0.0.0
PORT                | PORT, OPENSHIFT_NODEJS_PORT | 8080
HOSTNAME            | OPENSHIFT_APP_DNS  | localhost
APP_NAME            | OPENSHIFT_APP_NAME, APP_NAME | APP_NAME
MONGODB_DB_URL      | OPENSHIFT_MONGODB_DB_URL, MONGODB_DB_URL | mongodb://127.0.0.1:27017
POSTGRESQL_DB_URL   | OPENSHIFT_POSTGRESQL_DB_URL, POSTGRESQL_DB_URL | postgresql://127.0.0.1:5432
MYSQLDB_DB_URL      | OPENSHIFT_MYSQLDB_DB_URL, MYSQLDB_DB_URL | mysql://127.0.0.1:3306

See [`config-chain`](https://github.com/dominictarr/config-chain/#configchain-lives-to-serve-only-you) and the related [API docs](https://github.com/dominictarr/config-chain/#boring-api-docs) for advanced uses of the `cc`, and `config` objects returned by `config-multipaas`.
